import { Button, Card, Descriptions } from "antd";
import { useAppContext } from "../../Contexts/AppContext";
import { Constants, myFetch } from "../../utils";
import { useTranslation } from "react-i18next";
import { CreditCardOutlined } from "@ant-design/icons";
import { useState } from "react";

export default function PaymentPlan() {
  const { t } = useTranslation();
  const appContext = useAppContext();

  const [isRequestingBillingDetails, setIsRequestingBillingDetails] =
    useState(false);

  return (
    <Card
      title={t("paymentPlan.title")}
      extra={
        <Button
          type="link"
          icon={<CreditCardOutlined />}
          loading={isRequestingBillingDetails}
          onClick={() => {
            setIsRequestingBillingDetails(true);

            myFetch({
              method: "GET",
              url: "/payment/portal",
            })
              .then((response) => {
                console.log("response", response);

                window.location.href = response.url;
              })
              .catch((error) => {
                console.error("error", error);
                setIsRequestingBillingDetails(false);
              });
          }}
        >
          {t("paymentPlan.buttonUpdateBillingDetails")}
        </Button>
      }
    >
      <Descriptions>
        <Descriptions.Item label={t("paymentPlan.plan")}>
          {Constants.PAYMENT_PLAN[appContext.paymentPlan].name}
        </Descriptions.Item>
        <Descriptions.Item
          label={t("paymentPlan.contentsOfSubscription.title")}
        >
          <>
            {t("paymentPlan.contentsOfSubscription.maxEmployees")}{" "}
            {Constants.PAYMENT_PLAN[appContext.paymentPlan].maxEmployees}
            <br />
            {t(
              "paymentPlan.contentsOfSubscription.calendarMaxFutureBookingDays"
            )}
            :{" "}
            {
              Constants.PAYMENT_PLAN[appContext.paymentPlan]
                .calendarMaxFutureBookingDays
            }
            <br />
          </>
        </Descriptions.Item>
      </Descriptions>
    </Card>
  );
}
